@@ -39,14 +39,34 @@ namespace Banshee.Dap
 {    
     public abstract class DapDevice : IEnumerable, IDisposable
     {
+        public class Property
+        {
+            private string name;
+            private string val;
+            
+            public string Name {
+                get {
+                    return name;
+                }
+                
+                internal set {
+                    name = value;
+                }
+            }
+            
+            public string Value {
+                get {
+                    return val;
+                }
+                
+                internal set {
+                    val = value;
+                }
+            }
+        }
+        
         public class PropertyTable : IEnumerable
         {
-            public class Property
-            {
-                public string Name;
-                public string Value;
-            }
-        
             private ArrayList properties = new ArrayList();
             
             private Property Find(string name)
@@ -89,11 +109,19 @@ namespace Banshee.Dap
             public IEnumerator GetEnumerator()
             {
                 foreach(Property property in properties) {
-                    yield return property.Name;
+                    yield return property;
                 }
             }
         }
-
+        
+        private static uint current_uid = 1;
+        private static uint NextUid {
+            get {
+                return current_uid++;
+            }
+        }
+        
+        private uint uid;
         private PropertyTable properties = new PropertyTable();
         private ArrayList tracks = new ArrayList(); 
         private ActiveUserEvent save_report_event;
@@ -117,6 +145,14 @@ namespace Banshee.Dap
             if(dap_attrs != null && dap_attrs.Length >= 1) {
                 type_properties = dap_attrs[0] as DapProperties;
             }
+            
+            uid = NextUid;
+        }
+        
+        public uint Uid {
+            get {
+                return uid;
+            }
         }
         
         public IEnumerator GetEnumerator()
@@ -197,7 +233,7 @@ namespace Banshee.Dap
         protected virtual void OnTracksCleared()
         {
         }
-        
+
         public virtual void Eject()
         {
             EventHandler handler = Ejected;
@@ -473,7 +509,20 @@ namespace Banshee.Dap
          
         public virtual Gdk.Pixbuf GetIcon(int size)
         {
-            return null;
+            Gdk.Pixbuf pixbuf = IconThemeUtils.LoadIcon("multimedia-player", size);
+            if(pixbuf == null) {
+                return IconThemeUtils.LoadIcon("gnome-dev-ipod", size);
+            }
+            
+            return pixbuf;
+        }
+        
+        public virtual void SetName(string name)
+        {
+        }
+        
+        public virtual void SetOwner(string owner)
+        {
         }
         
         public PropertyTable Properties {
@@ -506,8 +555,38 @@ namespace Banshee.Dap
             }
         }
         
+        public virtual string GenericName {
+            get {
+                return "DAP";
+            }
+        }
+        
+        public string HalUdi {
+            get {
+                return HalDevice.Udi;
+            }
+        }
+        
+        public bool CanSetName {
+            get {
+                return ReflectionUtil.IsVirtualMethodImplemented(GetType(), "SetName");
+            }
+        }
+        
+        public bool CanSetOwner {
+            get {
+                return ReflectionUtil.IsVirtualMethodImplemented(GetType(), "SetOwner");
+            }
+        }
+        
+        public virtual string Owner {
+            get {
+                return Catalog.GetString("Unknown");
+            }
+        }
+        
         public abstract void Synchronize();
-        public abstract string Name { get; set; }
+        public abstract string Name { get; }
         public abstract ulong StorageCapacity { get; }
         public abstract ulong StorageUsed { get; }
         public abstract bool IsReadOnly { get; }
