@@ -36,10 +36,21 @@ namespace Banshee.Base
     {
         private static GConf.Client gconf_client;
         private static string library_location;
+        private static NetworkDetect network_detect;
+        private static ActionManager action_manager;
         
         static Globals()
         {
             gconf_client = new GConf.Client();
+            network_detect = NetworkDetect.Instance;
+            action_manager = new ActionManager();
+            Banshee.Plugins.PluginCore.Initialize();
+        }
+        
+        public static void Dispose()
+        {
+            network_detect.Dispose();
+            Banshee.Plugins.PluginCore.Dispose();
         }
         
         public static GConf.Client Configuration {
@@ -57,5 +68,17 @@ namespace Banshee.Base
                 library_location = value;
             }
         }
+        
+        public static NetworkDetect Network {
+            get {
+                return network_detect;
+            }
+        }
+        
+        public static ActionManager ActionManager {
+            get {
+                return action_manager;
+            }
+        }
     }
 }
