@@ -34,6 +34,7 @@ using System.IO;
 using System.Reflection;
 using System.Text;
 using System.Text.RegularExpressions; 
+using System.Diagnostics;
 using Mono.Unix;
  
 namespace Banshee.Base
@@ -68,19 +69,87 @@ namespace Banshee.Base
         
         public static string BytesToString(ulong bytes)
         {
-            ulong mb = bytes / (1024 * 1024);
+            double mb = (double)bytes / 1048576.0;
+            return mb > 1024.0
+                ? String.Format(Catalog.GetString("{0:0.00} GB"), mb / 1024.0)
+                : String.Format(Catalog.GetString("{0} MB"), Math.Round(mb));
+        }
+        
+        public static bool UnmountVolume(string device)
+        {
+            try {
+                if(ExecProcess("pumount", device) != 0) {
+                    throw new ApplicationException("pumount returned error");
+                }
+                
+                return true;
+            } catch(Exception) {
+                try {
+                    return ExecProcess("umount", device) == 0;
+                } catch(Exception) {
+                }
+            }
+            
+            return false;
+        }
+        
+        public static int ExecProcess(string command, string args)
+        {
+            Process process = Process.Start(command, args);
+            process.WaitForExit();
+            return process.ExitCode;
+        }
+        
+        public static Gdk.Color ColorBlend(Gdk.Color a, Gdk.Color b)
+        {
+            // at some point, might be nice to allow any blend?
+            double blend = 0.5;
 
-            if (mb > 1024)
-                return String.Format(Catalog.GetString("{0} GB"), mb / 1024);
-            else
-                return String.Format(Catalog.GetString("{0} MB"), mb);
+            if(blend < 0.0 || blend > 1.0) {
+                throw new ApplicationException("blend < 0.0 || blend > 1.0");
+            }
+            
+            double blendRatio = 1.0 - blend;
+
+            int aR = a.Red >> 8;
+            int aG = a.Green >> 8;
+            int aB = a.Blue >> 8;
+
+            int bR = b.Red >> 8;
+            int bG = b.Green >> 8;
+            int bB = b.Blue >> 8;
+
+            double mR = aR + bR;
+            double mG = aG + bG;
+            double mB = aB + bB;
+
+            double blR = mR * blendRatio;
+            double blG = mG * blendRatio;
+            double blB = mB * blendRatio;
+
+            Gdk.Color color = new Gdk.Color((byte)blR, (byte)blG, (byte)blB);
+            Gdk.Colormap.System.AllocColor(ref color, true, true);
+            return color;
+        }
+    }
+    
+    public static class ReflectionUtil
+    {
+        public static bool IsVirtualMethodImplemented(Type type, string methodName)
+        {
+            MethodInfo methodInfo = type.GetMethod(methodName);
+            
+            if(methodInfo == null) {
+                return false;
+            }
+            
+            return methodInfo.IsVirtual ? methodInfo != methodInfo.GetBaseDefinition() : true;
         }
     }
     
     public class DateTimeUtil
     {
-        public static readonly DateTime LocalUnixEpoch = 
-            new DateTime(1970, 1, 1).ToLocalTime();
+        public static readonly DateTime LocalUnixEpoch = new DateTime(1970, 1, 1).ToLocalTime();
 
         public static DateTime ToDateTime(long time)
         {
