@@ -214,7 +214,7 @@ namespace Banshee.Dap.Ipod
         
         public override Gdk.Pixbuf GetIcon(int size)
         {
-            string prefix = "portable-media-";
+            string prefix = "multimedia-player-";
             string id = null;
 
             switch(device.Model) {
@@ -237,30 +237,36 @@ namespace Banshee.Dap.Ipod
                     break;
             }
             
-            string path = ConfigureDefines.ICON_THEME_DIR 
-                + String.Format("{0}x{0}", size)
-                + Path.DirectorySeparatorChar
-                + "extras" 
-                + Path.DirectorySeparatorChar
-                + "devices" + 
-                + Path.DirectorySeparatorChar
-                + prefix + id + ".png";
-                
-            try {
-                return new Gdk.Pixbuf(path);
-            } catch(Exception) {
-                return base.GetIcon(size);
+            Gdk.Pixbuf icon = IconThemeUtils.LoadIcon(prefix + id, size);
+            
+            if(icon != null) {
+                return icon;
             }
+            
+            return base.GetIcon(size);
+        }
+        
+        public override void SetName(string name)
+        {
+            device.Name = name;
+            device.Save();
+        }
+        
+        public override void SetOwner(string owner)
+        {
+            device.UserName = owner;
+            device.Save();
         }
         
         public override string Name {
             get {
                 return device.Name;
             }
-            
-            set {
-                device.Name = value;
-                InvokePropertiesChanged();
+        }
+        
+        public override string Owner {
+            get {
+                return device.UserName;
             }
         }
         
@@ -287,5 +293,11 @@ namespace Banshee.Dap.Ipod
                 return true;
             }
         }
+        
+        public override string GenericName {
+            get {
+                return "iPod";
+            }
+        }
     }
 }
