@@ -29,37 +29,48 @@
  
 using System;
 using DBus;
+using Banshee.Base;
 
 namespace Banshee
 {
     public class DBusServer
     {
-        private static DBusServer instance = null;
-        
         private Service service;
-            
-        public static DBusServer Instance
-        {
+        
+        private static DBusServer instance = null;
+        public static DBusServer Instance {
             get {
-                if(instance == null)
+                if(instance == null) {
                     instance = new DBusServer();
+                }
+                
                 return instance;
             }
         }
         
         public DBusServer()
         {
-            service = new Service(Bus.GetSessionBus(), "org.gnome.Banshee");
+            try {
+                service = new Service(Bus.GetSessionBus(), "org.gnome.Banshee");
+            } catch(Exception e) {
+                LogCore.Instance.PushWarning("Could not connect to D-Bus", 
+                    "D-Bus support will be disabled for this instance: " + e.Message,
+                    false);
+            }
         }
         
         public void RegisterObject(object o, string path)
         {
-            service.RegisterObject(o, path);
+            if(service != null) {
+                service.RegisterObject(o, path);
+            }
         }
         
         public void UnregisterObject(object o)
         {
-            service.UnregisterObject(o);
+            if(service != null) {
+                service.UnregisterObject(o);
+            }
         }
     }
     
@@ -68,49 +79,49 @@ namespace Banshee
     {
         private Gtk.Window mainWindow;
         private PlayerUI PlayerUI;
-        private Core core;
-        
         public static BansheeCore FindInstance()
         {
             Connection connection = Bus.GetSessionBus();
             Service service = Service.Get(connection, "org.gnome.Banshee");        
-            return (BansheeCore)service.GetObject(typeof(BansheeCore), 
-                "/org/gnome/Banshee/Core");
+            return (BansheeCore)service.GetObject(typeof(BansheeCore), "/org/gnome/Banshee/Core");
         }
         
-        public BansheeCore(Gtk.Window mainWindow, PlayerUI ui, Core core)
+        public BansheeCore(Gtk.Window mainWindow, PlayerUI ui)
         {
             this.mainWindow = mainWindow;
             this.PlayerUI = ui;
-            this.core = core;
         }
         
         [Method]
         public virtual void PresentWindow()
         {
-            if(mainWindow != null)
+            if(mainWindow != null) {
                 mainWindow.Present();
+            }
         }
         
         [Method]
         public virtual void ShowWindow()
         {
-            if(mainWindow != null)
+            if(mainWindow != null) {
                 mainWindow.Show();
+            }
         }
         
         [Method]
         public virtual void HideWindow()
         {
-            if(mainWindow != null)
+            if(mainWindow != null) {
                 mainWindow.Hide();
+            }
         }
         
         [Method]
         public virtual void TogglePlaying()
         {
-            if(PlayerUI != null)
-                PlayerUI.TogglePlaying();
+            if(PlayerUI != null) {
+                PlayerUI.PlayPause();
+            }
         }
         
         [Method]
@@ -121,41 +132,52 @@ namespace Banshee
             }
             
             if(PlayerUI != null && !HaveTrack) {
-                PlayerUI.TogglePlaying();
+                PlayerUI.PlayPause();
             }
             
-            if(!core.Player.Playing) {
-                PlayerUI.TogglePlaying();
+            if(!PlayerEngineCore.ActivePlayer.Playing) {
+                PlayerUI.PlayPause();
             }
         }
         
         [Method]
         public virtual void Pause()
         {
-            if(HaveTrack && core.Player.Playing) {
-                PlayerUI.TogglePlaying();
+            if(HaveTrack && PlayerEngineCore.ActivePlayer.Playing) {
+                PlayerUI.PlayPause();
             }
         }
         
         [Method]
         public virtual void Next()
         {
-            if(PlayerUI != null)
+            if(PlayerUI != null) {
                 PlayerUI.Next();
+            }
         }
         
         [Method]
         public virtual void Previous()
         {
-            if(PlayerUI != null)
+            if(PlayerUI != null) {
                 PlayerUI.Previous();
+            }
         }
 
         [Method]
         public virtual void SelectAudioCd(string device)
         {
-            if(PlayerUI != null)
+            if(PlayerUI != null) {
                 PlayerUI.SelectAudioCd(device);
+            }
+        }
+        
+        [Method]
+        public virtual void SelectDap(string device)
+        {
+            if(PlayerUI != null) {
+                PlayerUI.SelectDap(device);
+            }
         }
         
         private bool HaveTrack {
@@ -167,49 +189,97 @@ namespace Banshee
         [Method]
         public virtual string GetPlayingArtist()
         {
-            return HaveTrack ? PlayerUI.ActiveTrackInfo.Artist : null;
+            return HaveTrack ? PlayerUI.ActiveTrackInfo.Artist : String.Empty;
         }
         
         [Method]
         public virtual string GetPlayingAlbum()
         {
-            return HaveTrack ? PlayerUI.ActiveTrackInfo.Album : null;
+            return HaveTrack ? PlayerUI.ActiveTrackInfo.Album : String.Empty;
         }
         
         [Method]
         public virtual string GetPlayingTitle()
         {
-            return HaveTrack ? PlayerUI.ActiveTrackInfo.Title : null;
+            return HaveTrack ? PlayerUI.ActiveTrackInfo.Title : String.Empty;
         }
         
         [Method]
         public virtual string GetPlayingGenre()
         {
-            return HaveTrack ? PlayerUI.ActiveTrackInfo.Genre : null;
+            return HaveTrack ? PlayerUI.ActiveTrackInfo.Genre : String.Empty;
         }
         
         [Method]
         public virtual string GetPlayingUri()
         {
-            return HaveTrack ? PlayerUI.ActiveTrackInfo.Uri.AbsoluteUri : null;
+            return HaveTrack ? PlayerUI.ActiveTrackInfo.Uri.AbsoluteUri : String.Empty;
         }
         
         [Method]
         public virtual int GetPlayingDuration()
         {
-            return HaveTrack ? (int)core.Player.Length : -1;
+            return HaveTrack ? (int)PlayerEngineCore.ActivePlayer.Length : -1;
         }
         
         [Method]
         public virtual int GetPlayingPosition()
         {
-            return HaveTrack ? (int)core.Player.Position : -1;
+            return HaveTrack ? (int)PlayerEngineCore.ActivePlayer.Position : -1;
+        }
+        
+        [Method]
+        public virtual string GetPlayingCoverArtFileName()
+        {
+            return HaveTrack ? PlayerUI.ActiveTrackInfo.CoverArtFileName : String.Empty;
         }
         
         [Method]
         public virtual int GetPlayingStatus()
         {
-            return core.Player.Playing ? 1 : (core.Player.Loaded ? 0 : -1);
+            return PlayerEngineCore.ActivePlayer.Playing ? 1 : (PlayerEngineCore.ActivePlayer.Loaded ? 0 : -1);
+        }
+        
+        [Method]
+        public virtual void SetVolume(int volume)
+        {
+            if(PlayerUI != null) {
+                PlayerUI.Volume = volume;
+            }
+        }
+
+        [Method]
+        public virtual void IncreaseVolume()
+        {
+            if(PlayerUI != null) {
+                PlayerUI.Volume += PlayerUI.VolumeDelta;
+            }
+        }
+        
+        [Method]
+        public virtual void DecreaseVolume()
+        {
+            if(PlayerUI != null) {
+                PlayerUI.Volume -= PlayerUI.VolumeDelta;
+            }
+        }
+        
+        [Method]
+        public virtual void SetPlayingPosition(int position)
+        {
+            PlayerEngineCore.ActivePlayer.Position = (uint)position;
+        }
+        
+        [Method]
+        public virtual void SkipForward()
+        {
+            PlayerEngineCore.ActivePlayer.Position += PlayerUI.SkipDelta;
+        }
+        
+        [Method]
+        public virtual void SkipBackward()
+        {
+            PlayerEngineCore.ActivePlayer.Position -= PlayerUI.SkipDelta;
         }
     }
 }
