@@ -191,7 +191,8 @@ namespace Banshee
         Playlist = 2,
         Ipod = 3,
         AudioCd = 4,
-        Dap = 5
+        Dap = 5,
+        LocalQueue = 6
     }
 
     public abstract class Source
@@ -267,10 +268,17 @@ namespace Banshee
     
     public class LibrarySource : Source
     {
-        public LibrarySource() : base(Catalog.GetString("Library"), 
-          SourceType.Library)
+        public LibrarySource() : base(Catalog.GetString("Library"), SourceType.Library)
         {
-              canRename = false;
+            canRename = false;
+            
+            string username = Utilities.GetRealName();
+            
+            if(username != null && username != String.Empty) {
+                username += (username[username.Length - 1] == 's' ? "'" : "'s") + " ";
+            }
+            
+            name = username + Catalog.GetString("Music Library");
         }
         
         public override int Count
@@ -281,6 +289,54 @@ namespace Banshee
         }
     }
     
+    public class LocalQueueSource : Source
+    {
+        private ArrayList tracks = new ArrayList();
+        
+        private static LocalQueueSource instance;
+        public static LocalQueueSource Instance {
+            get {
+                if(instance == null) {
+                    instance = new LocalQueueSource();
+                }
+                
+                return instance;
+            }
+        }
+        
+        public LocalQueueSource() : base(Catalog.GetString("The Frobnicator"), SourceType.LocalQueue)
+        {
+            canRename = false;
+            
+            foreach(string file in Core.ArgumentQueue.Files) {
+                try {
+                    Uri uri = file.StartsWith("file://") ? new Uri(file) : PathUtil.PathToFileUri(file);
+                    if(!System.IO.File.Exists(uri.LocalPath)) {
+                        uri = PathUtil.PathToFileUri(System.Environment.CurrentDirectory + 
+                            System.IO.Path.DirectorySeparatorChar + file);
+                    }
+                    
+                    tracks.Add(new FileTrackInfo(uri));
+                } catch(Exception e) {
+                    Console.WriteLine("Could not load: {0}", e.Message);
+                }
+            }
+        }
+        
+        public override int Count {
+            get {
+                return tracks.Count;
+            }
+        }
+        
+        public ICollection Tracks {
+            get {
+                return tracks;
+            }
+        }
+            
+    }
+    
     public class PlaylistSource : Source
     {
         int count = -1;
@@ -330,16 +386,19 @@ namespace Banshee
         public DapSource(Banshee.Dap.DapDevice device) : base(device.Name, SourceType.Dap)
         {
             this.device = device;
-            canRename = true;
+            canRename = device.CanSetName;
             canEject = true;
         }
         
         public override bool UpdateName(string oldName, string newName)
         {
+            if(!device.CanSetName) {
+                return true;
+            }
+        
             if(oldName == null || !oldName.Equals(newName)) {
-                device.Name = newName;
+                device.SetName(newName);
                 name = newName;
-                device.Save();
             }
             
             return true;
@@ -380,16 +439,6 @@ namespace Banshee
                 return (double)device.StorageUsed / (double)device.StorageCapacity;
             }
         }
-        
-        private static string BytesToString(ulong bytes)
-        {
-            ulong mb = bytes / (1024 * 1024);
-
-            if (mb > 1024)
-                return String.Format(Catalog.GetString("{0} GB"), mb / 1024);
-            else
-                return String.Format(Catalog.GetString("{0} MB"), mb);
-        }
 
         public string DiskUsageString
         {
@@ -397,8 +446,8 @@ namespace Banshee
                 // Translators: iPod disk usage. Each {N} is something like "100 MB"
                 return String.Format(
                     Catalog.GetString("{0} of {1}"),
-                    BytesToString(device.StorageUsed),
-                    BytesToString(device.StorageCapacity));
+                    Utilities.BytesToString(device.StorageUsed),
+                    Utilities.BytesToString(device.StorageCapacity));
             }
         }
 
@@ -408,7 +457,7 @@ namespace Banshee
                 // Translators: iPod disk usage. {0} is something like "100 MB"
                 return String.Format(
                     Catalog.GetString("({0} Remaining)"),
-                    BytesToString(device.StorageCapacity - device.StorageUsed));
+                    Utilities.BytesToString(device.StorageCapacity - device.StorageUsed));
             }
         }
         
@@ -419,193 +468,6 @@ namespace Banshee
         }
     }
 
-    /*public class IpodSource : Source
-    {
-        private IPod.Device device;
-        private ArrayList tracks = new ArrayList();
-        private ArrayList removeTracks = new ArrayList();
-        private bool needSync = false;
-        public bool IsSyncing;
-        
-        public IpodSource(IPod.Device device) : base(device.Name, 
-            SourceType.Ipod)
-        {
-            this.device = device;
-            canEject = true;
-            canRename = true;
-            
-            Refresh();
-        }
-        
-        private void Refresh()
-        {
-            tracks.Clear();
-            removeTracks.Clear();
-            needSync = false;
-            foreach(IPod.Song song in device.SongDatabase.Songs)
-                tracks.Add(new IpodTrackInfo(song));
-        }
-        
-        public void SetSourceName(string name)
-        {
-          this.name = name;
-        }
-        
-        public override bool UpdateName(string oldName, string newName)
-        {
-            if(oldName == null || !oldName.Equals(newName)) {
-                device.Name = newName;
-                name = newName;
-                device.Save();
-            }
-            
-            return true;
-        }
-        
-        public override int Count
-        {
-            get {
-                //return device.SongDatabase.Songs.Length;
-                return tracks.Count;
-            }
-        }
-        
-        public IPod.Device Device
-        {
-            get {
-                return device;
-            }
-        }
-        
-        public override bool Eject()
-        {
-            device.Eject();
-            return true;
-        }
-
-        public double DiskUsageFraction
-        {
-            get {
-                return (double)device.VolumeUsed /
-                    (double)device.VolumeSize;
-            }
-        }
-        
-        public bool NeedSync
-        {
-            get {
-                if(needSync || removeTracks.Count > 0)
-                    return true;
-                
-                foreach(IpodTrackInfo iti in tracks) {
-                    if(iti.NeedSync)
-                        return true;
-                }
-                
-                return false;
-            }
-        }
-        
-        public ArrayList Tracks
-        {
-            get {
-                return tracks;
-            }
-        }
-        
-        private bool ExistsOnIpod(LibraryTrackInfo libTrack)
-        {
-            foreach(IPod.Song song in device.SongDatabase.Songs) {
-                if(IpodMisc.TrackCompare(libTrack, song))
-                    return true;
-            }
-            
-            return false;
-        }
-        
-        public void QueueForSync(LibraryTrackInfo ti)
-        {
-            if(ti == null)
-                return;
-                
-            foreach(IpodTrackInfo iti in tracks) {
-                if(iti.LibraryTrack != null && ti.Equals(iti.LibraryTrack))
-                    return;
-            }
-            
-            if(ExistsOnIpod(ti))
-                return;
-            
-            tracks.Add(new IpodTrackInfo(device, ti));
-        }
-        
-        public void Remove(IpodTrackInfo iti)
-        {
-            if(!iti.NeedSync)
-                needSync = true;
-            device.SongDatabase.RemoveSong(iti.Song);
-            tracks.Remove(iti);
-            removeTracks.Add(iti);
-        }
-        
-        public IpodSync Sync(bool full)
-        {
-            IpodSync sync;
-            
-            if(full)
-                sync = new IpodSync(device);
-            else
-                sync = new IpodSync(device, tracks, removeTracks);
-                
-            sync.SyncStarted += OnIpodSyncStarted;
-            sync.SyncCompleted += OnIpodSyncCompleted;
-            
-            return sync;
-        }
-        
-        private void OnIpodSyncStarted(object o, EventArgs args)
-        {
-            IsSyncing = true;
-        }
-        
-        private void OnIpodSyncCompleted(object o, EventArgs args)
-        {
-            IsSyncing = false;
-            Refresh();
-        }
-
-        private static string BytesToString(ulong bytes)
-        {
-            ulong mb = bytes / (1024 * 1024);
-
-            if (mb > 1024)
-                return String.Format(Catalog.GetString("{0} GB"), mb / 1024);
-            else
-                return String.Format(Catalog.GetString("{0} MB"), mb);
-        }
-
-        public string DiskUsageString
-        {
-            get {
-                // Translators: iPod disk usage. Each {N} is something like "100 MB"
-                return String.Format(
-                    Catalog.GetString("{0} of {1}"),
-                    BytesToString(device.VolumeUsed),
-                    BytesToString(device.VolumeSize));
-            }
-        }
-
-        public string DiskAvailableString
-        {
-            get {
-                // Translators: iPod disk usage. {0} is something like "100 MB"
-                return String.Format(
-                    Catalog.GetString("({0} Remaining)"),
-                    BytesToString(device.VolumeAvailable));
-            }
-        }
-    }*/
-    
     public class AudioCdSource : Source
     {
         private AudioCdDisk disk;
