@@ -74,7 +74,7 @@ namespace Banshee
     
         private void SyncPlayingIter()
         {
-            if(Core.Instance.Player.Track == null) {
+            if(PlayerEngineCore.ActivePlayer.Track == null) {
                 playingIter = TreeIter.Zero;
             } else {
                 for(int i = 0, n = Count(); i < n; i++) {
@@ -84,7 +84,7 @@ namespace Banshee
                         
                     TrackInfo ti = IterTrackInfo(iter);
                     
-                    if(Core.Instance.Player.Track.Uid == ti.Uid) {
+                    if(PlayerEngineCore.ActivePlayer.Track.Uid == ti.Uid) {
                         playingIter = iter;
                         break;
                     }
@@ -145,6 +145,14 @@ namespace Banshee
                 RaiseUpdated(this, new EventArgs());
             }
         }
+        
+        public void LoadFromLocalQueue()
+        {
+            ClearModel();
+            foreach(TrackInfo ti in LocalQueueSource.Instance.Tracks) {
+                AddTrack(ti, false);
+            }
+        }
 
         public void LoadFromPlaylist(string name)
         {
@@ -170,7 +178,7 @@ namespace Banshee
         {
             ClearModel();
             
-            foreach(Banshee.Dap.DapTrackInfo track in dapSource.Device) {
+            foreach(TrackInfo track in dapSource.Device) {
                 AddTrack(track);
             }
             
