@@ -78,7 +78,7 @@ namespace Banshee
 
         public PreferencesWindow()
         {
-            glade = new Glade.XML(null, "preferences.glade", "WindowPreferences", null);
+            glade = new Glade.XML(null, "banshee.glade", "WindowPreferences", null);
             glade.Autoconnect(this);
             
             ((Image)glade["ImageLibraryTab"]).Pixbuf = 
@@ -540,7 +540,7 @@ namespace Banshee
         
         private void SaveEngineSettings()
         {
-            if(SelectedEngine.ConfigName != Core.Instance.Player.ConfigName) {
+            if(SelectedEngine.ConfigName != PlayerEngineCore.ActivePlayer.ConfigName) {
                 Core.GconfClient.Set(GConfKeys.PlayerEngine, SelectedEngine.ConfigName);
                 string msg = 
                     String.Format(
