@@ -138,6 +138,10 @@ namespace Banshee
             store.Clear();
             store.AppendValues(new LibrarySource());
             
+            if(LocalQueueSource.Instance.Count > 0) {
+                store.AppendValues(LocalQueueSource.Instance);
+            }
+            
             if(Core.Instance.AudioCdCore != null) {
                 try {
                     foreach(AudioCdDisk disk in Core.Instance.AudioCdCore.Disks)
@@ -449,6 +453,22 @@ namespace Banshee
             }
         }
         
+        public void ResetHighlight()
+        {
+            TreeIter iter = TreeIter.Zero;
+            
+            for(int i = 0, n = store.IterNChildren(); i < n; i++) {
+                if(!store.IterNthChild(out iter, i))
+                    continue;
+                
+                object obj = store.GetValue(iter, 0);
+                
+                if(obj == SelectedSource) {
+                    Selection.SelectIter(iter);
+                }
+            }
+        }
+        
         public Source HighlightedSource
         {
             get {
@@ -468,6 +488,8 @@ namespace Banshee
                 QueueDraw();
             });
         }
+        
+        public bool EditingRow = false;
     }
 
     public class SourceRowRenderer : CellRendererText
@@ -476,12 +498,7 @@ namespace Banshee
         public bool Italicized = false;
         public Source source;
         public SourceView view;
-        
-        ~SourceRowRenderer()
-        {
-            Dispose();
-        }
-        
+
         public SourceRowRenderer()
         {
             Editable = true;
@@ -516,37 +533,6 @@ namespace Banshee
             height = text_h + 5;
         }
         
-        private static Gdk.Color ColorBlend(Gdk.Color a, Gdk.Color b)
-        {
-            // at some point, might be nice to allow any blend?
-            double blend = 0.5;
-        
-            if(blend < 0.0 || blend > 1.0)
-                throw new ApplicationException("blend < 0.0 || blend > 1.0");
-        
-            double blendRatio = 1.0 - blend;
-        
-            int aR = a.Red >> 8;
-            int aG = a.Green >> 8;
-            int aB = a.Blue >> 8;
-            
-            int bR = b.Red >> 8;
-            int bG = b.Green >> 8;
-            int bB = b.Blue >> 8;
-            
-            double mR = aR + bR;
-            double mG = aG + bG;
-            double mB = aB + bB;
-            
-            double blR = mR * blendRatio;
-            double blG = mG * blendRatio;
-            double blB = mB * blendRatio;
-            
-            Gdk.Color color = new Gdk.Color((byte)blR, (byte)blG, (byte)blB);
-            Gdk.Colormap.System.AllocColor(ref color, true, true);
-            return color;
-        }
-        
         protected override void Render(Gdk.Drawable drawable, 
             Widget widget, Gdk.Rectangle background_area, 
             Gdk.Rectangle cell_area, Gdk.Rectangle expose_area, 
@@ -565,17 +551,20 @@ namespace Banshee
             
             switch(source.Type) {
                 case SourceType.Playlist:
-                    icon = Pixbuf.LoadFromResource("source-playlist.png");
+                    icon = IconThemeUtils.LoadIcon(22, "source-playlist");
                     break;
                 case SourceType.Dap:
                     icon = (source as DapSource).Device.GetIcon(22);
                     break;
                 case SourceType.AudioCd:
-                    icon = Pixbuf.LoadFromResource("source-cd-audio.png");
+                    icon = IconThemeUtils.LoadIcon(22, "media-cdrom", "gnome-dev-cdrom-audio", "source-cd-audio");
+                    break;
+                case SourceType.LocalQueue:
+                    icon = IconThemeUtils.LoadIcon(22, "source-localqueue");
                     break;
                 case SourceType.Library:
                 default:
-                    icon = Pixbuf.LoadFromResource("source-library.png");
+                    icon = IconThemeUtils.LoadIcon(22, "source-library");
                     break;
             }
             
@@ -650,7 +639,7 @@ namespace Banshee
                 modGC.Copy(widget.Style.TextGC(state));
                 Gdk.Color fgcolor = widget.Style.Foreground(state);
                 Gdk.Color bgcolor = widget.Style.Background(state);
-                modGC.RgbFgColor = ColorBlend(fgcolor, bgcolor);
+                modGC.RgbFgColor = Utilities.ColorBlend(fgcolor, bgcolor);
             } 
             
             drawable.DrawLayout(modGC,
@@ -668,6 +657,9 @@ namespace Banshee
             text.Text = source.Name;
             text.path = path;
             text.Show();
+            
+            view.EditingRow = true;
+            
             return text;
         }
         
@@ -676,6 +668,7 @@ namespace Banshee
             CellEdit edit = o as CellEdit;
             if(view == null)
                 return;
+            view.EditingRow = false;
             view.UpdateRow(new TreePath(edit.path), edit.Text);
         }
     }
